getCapabilities method
Returns the capabilities of the torch on the current platform.
Implementation
Future<TorchCapabilities> getCapabilities() async {
return await TorchFlashlight.getCapabilities();
}
Returns the capabilities of the torch on the current platform.
Future<TorchCapabilities> getCapabilities() async {
return await TorchFlashlight.getCapabilities();
}