setTorchStrength method
Sets the torch strength level.
strength should be between 0 and getMaxTorchStrength().
Throws an error if not supported by the device.
Implementation
@override
Future<void> setTorchStrength(int strength) async {
throw UnsupportedError(
'Torch strength control is not supported on web platform');
}